@@ -63,7 +63,6 @@ class DatabricksSqlOperator(SQLExecuteQueryOperator):
     :param output_format: format of output data if ``output_path` is specified.
         Possible values are ``csv``, ``json``, ``jsonl``. Default is ``csv``.
     :param csv_params: parameters that will be passed to the ``csv.DictWriter`` class used to write CSV data.
-    :param do_xcom_push: If True, then the result of SQL executed will be pushed to an XCom.
     """
 
     template_fields: Sequence[str] = (
@@ -87,7 +86,6 @@ class DatabricksSqlOperator(SQLExecuteQueryOperator):
         http_headers: list[tuple[str, str]] | None = None,
         catalog: str | None = None,
         schema: str | None = None,
-        do_xcom_push: bool = False,
         output_path: str | None = None,
         output_format: str = "csv",
         csv_params: dict[str, Any] | None = None,
@@ -99,31 +97,43 @@ class DatabricksSqlOperator(SQLExecuteQueryOperator):
         self._output_path = output_path
         self._output_format = output_format
         self._csv_params = csv_params
-
-        client_parameters = {} if client_parameters is None else client_parameters
-        hook_params = kwargs.pop("hook_params", {})
-
-        self.hook_params = {
-            "http_path": http_path,
-            "session_configuration": session_configuration,
-            "sql_endpoint_name": sql_endpoint_name,
-            "http_headers": http_headers,
-            "catalog": catalog,
-            "schema": schema,
-            "caller": "DatabricksSqlOperator",
-            **client_parameters,
-            **hook_params,
-        }
+        self.http_path = http_path
+        self.sql_endpoint_name = sql_endpoint_name
+        self.session_configuration = session_configuration
+        self.client_parameters = {} if client_parameters is None else client_parameters
+        self.hook_params = kwargs.pop("hook_params", {})
+        self.http_headers = http_headers
+        self.catalog = catalog
+        self.schema = schema
 
     def get_db_hook(self) -> DatabricksSqlHook:
-        return DatabricksSqlHook(self.databricks_conn_id, **self.hook_params)
+        hook_params = {
+            "http_path": self.http_path,
+            "session_configuration": self.session_configuration,
+            "sql_endpoint_name": self.sql_endpoint_name,
+            "http_headers": self.http_headers,
+            "catalog": self.catalog,
+            "schema": self.schema,
+            "caller": "DatabricksSqlOperator",
+            **self.client_parameters,
+            **self.hook_params,
+        }
+        return DatabricksSqlHook(self.databricks_conn_id, **hook_params)
 
-    def _process_output(self, schema, results):
+    def _should_run_output_processing(self) -> bool:
+        return self.do_xcom_push or bool(self._output_path)
+
+    def _process_output(self, results: list[Any], descriptions: list[Sequence[Sequence] | None]) -> list[Any]:
         if not self._output_path:
-            return
+            return list(zip(descriptions, results))
         if not self._output_format:
             raise AirflowException("Output format should be specified!")
-        field_names = [field[0] for field in schema]
+        # Output to a file only the result of last query
+        last_description = descriptions[-1]
+        last_results = results[-1]
+        if last_description is None:
+            raise AirflowException("There is missing description present for the output file. .")
+        field_names = [field[0] for field in last_description]
         if self._output_format.lower() == "csv":
             with open(self._output_path, "w", newline="") as file:
                 if self._csv_params:
@@ -136,18 +146,19 @@ class DatabricksSqlOperator(SQLExecuteQueryOperator):
                 writer = csv.DictWriter(file, fieldnames=field_names, **csv_params)
                 if write_header:
                     writer.writeheader()
-                for row in results:
+                for row in last_results:
                     writer.writerow(row.asDict())
         elif self._output_format.lower() == "json":
             with open(self._output_path, "w") as file:
-                file.write(json.dumps([row.asDict() for row in results]))
+                file.write(json.dumps([row.asDict() for row in last_results]))
         elif self._output_format.lower() == "jsonl":
             with open(self._output_path, "w") as file:
-                for row in results:
+                for row in last_results:
                     file.write(json.dumps(row.asDict()))
                     file.write("\n")
         else:
             raise AirflowException(f"Unsupported output format: '{self._output_format}'")
+        return list(zip(descriptions, results))
 
 
 COPY_INTO_APPROVED_FORMATS = ["CSV", "JSON", "AVRO", "ORC", "PARQUET", "TEXT", "BINARYFILE"]
